@@ -13,7 +13,9 @@ def get_ecses():
     cli = ali_cli.AliCli(cfg.get('config', 'accesskeyid'),
                          cfg.get('config', 'accesskeysecret'),
                          cfg.get('config', 'regionids').split(','))
-    return [ecs for ecs in cli.ecses_iterator()]
+    ecses= [ecs for ecs in cli.ecses_iterator()]
+    ecses = sorted(ecses, key=lambda x: x.hostname, reverse=False)
+    return ecses
 
 
 @click.command()
