@@ -17,8 +17,10 @@ if not os.path.exists(ini_file):
     cfg.set('config','accesskeysecret',raw_input('accesskeysecret:'))
     cfg.set('config','regionids',raw_input('请输入regionids(","分隔):'))
     print('需要在配置文件中设置相应值,配置文件：',ini_file)
-    with open (ini_file,'+w') as f:
-        cfg.write(f)
+    f=open (ini_file,'w')
+    cfg.write(f)
+    f.flush()
+    f.close()
 
 def read_cfg():
     cfg = ConfigParser.RawConfigParser()
